@@ -17,12 +17,12 @@
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02111 USA.
+   Boston, MA 02110 USA.
 */
 
 #ifndef __NSAffineTransform_h_GNUSTEP_BASE_INCLUDE
@@ -41,6 +41,7 @@ typedef	struct {
   CGFloat	tY;
 } NSAffineTransformStruct;
 
+GS_EXPORT_CLASS
 @interface NSAffineTransform : NSObject <NSCopying, NSCoding>
 {
 #if GS_EXPOSE(NSAffineTransform)
@@ -48,8 +49,8 @@ typedef	struct {
   NSAffineTransformStruct	_matrix;
   BOOL _isIdentity;	// special case: A=D=1 and B=C=0
   BOOL _isFlipY;	// special case: A=1 D=-1 and B=C=0
-  BOOL _pad1;
-  BOOL _pad2;
+  BOOL _pad1 GS_UNUSED_IVAR;
+  BOOL _pad2 GS_UNUSED_IVAR;
 #endif
 }
 
