@@ -109,6 +109,7 @@ GS_EXPORT NSString* const NSLoadedClasses;
    bundle.
    </p>
 */
+GS_EXPORT_CLASS
 @interface NSBundle : NSObject
 {
 #if	GS_EXPOSE(NSBundle)
@@ -344,7 +345,7 @@ GS_EXPORT NSString* const NSLoadedClasses;
  */
 - (NSString*) localizedStringForKey: (NSString*)key
 			      value: (NSString*)value
-			      table: (NSString*)tableName;
+			      table: (NSString*)tableName NS_FORMAT_ARGUMENT(1);
 
 /** Returns the absolute path to the resources directory of the bundle.  */
 - (NSString*) resourcePath;
@@ -529,13 +530,12 @@ GS_EXPORT NSString* const NSLoadedClasses;
  *  not exist on disk.
  * </p>
  */
-+ (NSBundle *) bundleForLibrary: (NSString *)libraryName
-                        version: (NSString *)interfaceVersion;
++ (NSBundle *) bundleForLibrary: (NSString*)libraryName
+                        version: (NSString*)interfaceVersion;
 
-/** This method is a equivalent to bundleForLibrary:version: with a nil
- * version.
+/** Use +bundleForLibrary:version: instead.
  */
-+ (NSBundle *) bundleForLibrary: (NSString *)libraryName;
++ (NSBundle*) bundleForLibrary: (NSString*)libraryName NS_DEPRECATED();
 
 
 
@@ -564,7 +564,7 @@ GS_EXPORT NSString* const NSLoadedClasses;
  * Returns the Android asset for the given path if path is in main bundle
  * resources and asset exists.
  * Uses `AASSET_MODE_UNKNOWN` to open the asset if it exists.
- * The returned object must be released using AAsset_close().
+ * The returned object must be released using the AAsset_close function.
  */
 + (AAsset *) assetForPath: (NSString *)path;
 
@@ -572,14 +572,14 @@ GS_EXPORT NSString* const NSLoadedClasses;
  * Returns the Android asset for the given path if path is in main bundle
  * resources and asset exists.
  * Uses the given mode to open the AAsset if it exists.
- * The returned object must be released using AAsset_close().
+ * The returned object must be released using the AAsset_close function.
  */
 + (AAsset *) assetForPath: (NSString *)path withMode: (int)mode;
 
 /**
  * Returns the Android asset dir for the given path if path is in main bundle
  * resources and the asset directory exists.
- * The returned object must be released using AAssetDir_close().
+ * The returned object must be released using the AAssetDir_close function.
  */
 + (AAssetDir *) assetDirForPath: (NSString *)path;
 
