@@ -1,4 +1,4 @@
-/* Interface for NSXMLNode for GNUStep
+/**Interface for NSXMLNode for GNUStep
    Copyright (C) 2008 Free Software Foundation, Inc.
 
    Written by:  Richard Frith-Macdonald <rfm@gnu.org>
@@ -14,12 +14,12 @@
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+   Lesser General Public License for more details.
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02111 USA.
+   Boston, MA 02110 USA.
 */
 
 #ifndef __NSXMLNode_h_GNUSTEP_BASE_INCLUDE
@@ -75,27 +75,39 @@ typedef NSUInteger NSXMLNodeKind;
 // Output options
 //  NSXMLNodePrettyPrint
 
+/* This next class declaration is private for internal use by the base
+ * library developers ... it is present simply to make the compiler
+ * produce symbol information to be used when debugging.
+ */
+#if	defined(GSInternal)
+@class GSInternal;
+#endif
+
 /**
  * The most primitive unit in an XML document.
  */
+GS_EXPORT_CLASS
 @interface NSXMLNode : NSObject <NSCopying>
 {
-#if	GS_EXPOSE(NSXMLNode)
-@protected
-  void		*_handle;
-  NSXMLNodeKind _kind;
-  NSXMLNode     *_parent;
-  NSUInteger    _index;
-  id            _objectValue;
-#endif
 #if     GS_NONFRAGILE
+#  if	defined(GS_NSXMLNode_IVARS)
+@public GS_NSXMLNode_IVARS;
+#  endif
 #else
   /* Pointer to private additional data used to avoid breaking ABI
    * when we don't have the non-fragile ABI available.
    * Use this mechanism rather than changing the instance variable
    * layout (see Source/GSInternal.h for details).
+   * In this case, when compiled the variable is a public class pointer
+   * available so that the NSXMLNode subclasses within the base library
+   * can share the same variables, but when viewed from outside the
+   * base library itsself, it's an opaque pointer which must not be used.
    */
+#  if	defined(GSInternal)
+  @public GSInternal *_internal GS_UNUSED_IVAR;
+#  else
   @private id _internal GS_UNUSED_IVAR;
+#  endif
 #endif
 }
 
@@ -223,13 +235,13 @@ typedef NSUInteger NSXMLNodeKind;
  * Calls -initWithKind:options: using NSXMLNodeOptionsNone and
  * returns the result.
  */
-- (id) initWithKind: (NSXMLNodeKind)kind;
+- (id) initWithKind: (NSXMLNodeKind)theKind;
 
 /** <init />
  * Initialises the receiver as the specified kind of node and with the
  * specified options.
  */
-- (id) initWithKind: (NSXMLNodeKind)kind options: (NSUInteger)options;
+- (id) initWithKind: (NSXMLNodeKind)theKind options: (NSUInteger)theOptions;
 
 /** Return the level of the receiver within the tree of nodes.<br />
  *  A document or a node which is not inside another is at level 0.
@@ -263,7 +275,7 @@ typedef NSUInteger NSXMLNodeKind;
  * in order to avoid problems where the xpath syntax cannot cope with
  * multiple text nodes.
  */
-- (NSArray*) nodesForXPath: (NSString*)xpath error: (NSError**)error;
+- (NSArray*) nodesForXPath: (NSString*)anxpath error: (NSError**)error;
 
 /** Returns the data resulting from calling the query on the receiver.<br />
  * The same as objectsForXQuery:constants:error: without the constants.
@@ -370,7 +382,7 @@ typedef NSUInteger NSXMLNodeKind;
  * Returns the text of the receiver as XML (ie in the form it would have
  * in an XML document), with the specified options controlling it.
  */
-- (NSString*) XMLStringWithOptions: (NSUInteger)options;
+- (NSString*) XMLStringWithOptions: (NSUInteger)theOptions;
 
 @end
 
