@@ -34,8 +34,46 @@
 #import <GNUstepBase/GSConfig.h>
 
 #include <stdio.h>
-#include <objc/objc.h>
-#include <objc/objc-api.h>
+
+#if NeXT_RUNTIME
+ #include <objc/objc.h>
+ #include <objc/objc-class.h>
+ #include <objc/objc-runtime.h>
+ #ifndef _C_ATOM
+  #define _C_ATOM '%'
+ #endif
+ #define _F_CONST    0x01
+ #define _F_IN       0x01
+ #define _F_OUT      0x02
+ #define _F_INOUT    0x03
+ #define _F_BYCOPY   0x04
+ #define _F_ONEWAY   0x08
+ #define _C_CONST    'r'
+ #define _C_IN       'n'
+ #define _C_INOUT    'N'
+ #define _C_OUT      'o'
+ #define _C_BYCOPY   'O'
+ #define _C_ONEWAY   'V'
+#else				/* GNU Objective C Runtime */
+ #include <objc/objc.h>
+ #if defined (__GNU_LIBOBJC__)
+  #include <objc/runtime.h>
+ #else
+  #include <objc/objc-api.h>
+  #include <objc/encoding.h>
+ #endif
+#endif
+
+/*
+ * Hack for older compiler versions that don't have all defines
+ * needed in  objc-api.h
+ */
+#ifndef	_C_LNG_LNG
+#define	_C_LNG_LNG	'q'
+#endif
+#ifndef	_C_ULNG_LNG
+#define	_C_ULNG_LNG	'Q'
+#endif
 
 #if	OBJC2RUNTIME
 /* We have a real ObjC2 runtime.
@@ -44,11 +82,9 @@
 #else
 /* We emulate an ObjC2 runtime.
  */
-#include <ObjectiveC2/runtime.h>
+#include <ObjectiveC2/objc/runtime.h>
 #endif
 
-#include <stdarg.h>
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -220,30 +256,30 @@ GSObjCSetVal(NSObject *self, const char *key, id val, SEL sel,
  */
 
 /**
- * Deprecated ... use objc_getClassList()
+ * Deprecated ... use "objc_getClassList()".
  */
 GS_EXPORT unsigned int
 GSClassList(Class *buffer, unsigned int max, BOOL clearCache);
 
 /**
- * GSObjCClass() is deprecated ... use object_getClass()
+ * GSObjCClass() is deprecated ... use "object_getClass()".
  */
 GS_EXPORT Class GSObjCClass(id obj);
 
 /**
- * GSObjCSuper() is deprecated ... use class_getSuperclass()
+ * GSObjCSuper() is deprecated ... use "class_getSuperclass()".
  */
 GS_EXPORT Class GSObjCSuper(Class cls);
 
 /**
- * GSObjCIsInstance() is deprecated ... use object_getClass()
- * in conjunction with class_isMetaClass()
+ * GSObjCIsInstance() is deprecated ... use "object_getClass()"
+ * in conjunction with "class_isMetaClass()".
  */
 GS_EXPORT BOOL GSObjCIsInstance(id obj);
 
 /**
- * GSObjCIsClass() is deprecated ... use object_getClass()
- * in conjunction with class_isMetaClass()
+ * GSObjCIsClass() is deprecated ... use "object_getClass()"
+ * in conjunction with "class_isMetaClass()".
  */
 GS_EXPORT BOOL GSObjCIsClass(Class cls);
 
@@ -254,45 +290,46 @@ GS_EXPORT BOOL GSObjCIsClass(Class cls);
 GS_EXPORT BOOL GSObjCIsKindOf(Class cls, Class other);
 
 /**
- * GSClassFromName() is deprecated ... use objc_lookUpClass()
+ * GSClassFromName() is deprecated ... use "objc_lookUpClass()".
  */
 GS_EXPORT Class GSClassFromName(const char *name);
 
 /**
- * GSNameFromClass() is deprecated ... use class_getName()
+ * GSNameFromClass() is deprecated ... use "class_getName()".
  */
 GS_EXPORT const char *GSNameFromClass(Class cls);
 
 /**
- * GSClassNameFromObject() is deprecated ... use object_getClass()
- * in conjunction with class_getName()
+ * GSClassNameFromObject() is deprecated ... use "object_getClass()".
+ * in conjunction with "class_getName()".
  */
 GS_EXPORT const char *GSClassNameFromObject(id obj);
 
 /**
- * GSNameFromSelector() is deprecated ... use sel_getName()
+ * GSNameFromSelector() is deprecated ... use "sel_getName()".
  */
 GS_EXPORT const char *GSNameFromSelector(SEL sel);
 
 /**
- * GSSelectorFromName() is deprecated ... use sel_getUid()
+ * GSSelectorFromName() is deprecated ... use "sel_getUid()".
  */
 GS_EXPORT SEL
 GSSelectorFromName(const char *name);
 
 /**
- * Return the selector for the specified name and types.  Returns a nul
- * pointer if the name is nul.  Uses any available selector if the types
- * argument is nul. <br />
- * Creates a new selector if necessary.
+ * Return the selector for the specified name and types.<br />
+ * Returns a nul pointer if the name is nul.<br />
+ * Creates a new selector if necessary.<br />
+ * Code must NOT rely on this providing a selector with type information.
  */
 GS_EXPORT SEL
 GSSelectorFromNameAndTypes(const char *name, const char *types);
 
 /**
- * Return the type information from the specified selector.
+ * Return the type information from the specified selector.<br />
  * May return a nul pointer if the selector was a nul pointer or if it
- * was not typed.
+ * was not typed (or if the runtime does not support typed selectors).<br />
+ * Code must NOT rely on this providing any type information.
  */
 GS_EXPORT const char *
 GSTypesFromSelector(SEL sel);
@@ -305,6 +342,12 @@ GSTypesFromSelector(SEL sel);
 GS_EXPORT BOOL
 GSSelectorTypesMatch(const char *types1, const char *types2);
 
+/** Takes full type information and skips forward to the actual type
+ * as specified in the _C_... constants.
+ */
+GS_EXPORT const char *
+GSSkipTypeQualifierAndLayoutInfo(const char *types);
+
 /**
  * Returns a protocol object with the corresponding name.
  * This function searches the registered classes for any protocol
@@ -323,6 +366,16 @@ GSProtocolFromName(const char *name);
 GS_EXPORT void
 GSRegisterProtocol(Protocol *proto);
 
+/**
+ * A variant of protocol_getMethodDescription which recursively searches
+ * parent protocols if the requested selector isn't found in the given
+ * protocol.
+ *
+ * Returns a {NULL, NULL} structure if the requested selector couldn't be
+ * found.
+ */
+GS_EXPORT struct objc_method_description
+GSProtocolGetMethodDescriptionRecursive(Protocol *aProtocol, SEL aSel, BOOL isRequired, BOOL isInstance);
 
 /*
  * Unfortunately the definition of the symbols
@@ -342,7 +395,7 @@ typedef Ivar	GSIVar;
  * either the specified class only or also its superclasses.<br/>
  * To obtain the implementation pointer IMP use returnValue->method_imp
  * which should be safe across all runtimes.<br/>
- * It should be safe to use this function in +load implementations.<br/>
+ * It should be safe to use this function in "+load" implementations.<br/>
  * This function should currently (June 2004) be considered WIP.
  * Please follow potential changes (Name, parameters, ...) closely until
  * it stabilizes.
@@ -359,19 +412,19 @@ GS_EXPORT void
 GSFlushMethodCacheForClass (Class cls);
 
 /**
- * Deprecated .. use class_getInstanceVariable()
+ * Deprecated .. use "class_getInstanceVariable()".
  */
 GS_EXPORT GSIVar
 GSCGetInstanceVariableDefinition(Class cls, const char *name);
 
 /**
- * Deprecated .. use class_getInstanceVariable()
+ * Deprecated .. use "class_getInstanceVariable()".
  */
 GS_EXPORT GSIVar
 GSObjCGetInstanceVariableDefinition(Class cls, NSString *name);
 
 /**
- * GSObjCVersion() is deprecated ... use class_getVersion()
+ * GSObjCVersion() is deprecated ... use "class_getVersion()"
  */
 GS_EXPORT int GSObjCVersion(Class cls);
 
@@ -406,10 +459,19 @@ GSObjCAllSubclassesOfClass(Class cls);
 GS_EXPORT NSArray *
 GSObjCDirectSubclassesOfClass(Class cls);
 
+/** Function to change the class of the specified instance to newClass.
+ * This handles memory debugging issues in GNUstep-base and also
+ * deals with class finalisation issues in a garbage collecting
+ * environment, so you should use this function rather than attempting
+ * to swizzle class pointers directly.
+ */
+GS_EXPORT void
+GSClassSwizzle(id instance, Class newClass);
+
 #if GS_API_VERSION(GS_API_ANY,011500)
 
 GS_EXPORT const char *
-GSLastErrorStr(long error_id) GS_ATTRIB_DEPRECATED;
+GSLastErrorStr(long error_id) GS_DEPRECATED_FUNC;
 
 #endif
 
@@ -483,7 +545,7 @@ GSLastErrorStr(long error_id) GS_ATTRIB_DEPRECATED;
   if (__count > __max) \
     { \
       unsigned int	__tmp; \
-      __objects = (id*)objc_malloc(__count*sizeof(id)); \
+      __objects = (id*)malloc(__count*sizeof(id)); \
       __pairs = &__objects[__count/2]; \
       __objects[0] = firstObject; \
       va_start(__ap, firstObject); \
@@ -501,7 +563,7 @@ GSLastErrorStr(long error_id) GS_ATTRIB_DEPRECATED;
       va_end(__ap); \
     } \
   code; \
-  if (__objects != __buf) objc_free(__objects); \
+  if (__objects != __buf) free(__objects); \
 })
 
 /**
