@@ -42,6 +42,7 @@
 #import <Foundation/NSObject.h>
 #import <Foundation/NSString.h>
 #import <Foundation/NSDictionary.h>
+#import <Foundation/NSStream.h>
 #else
 #import <Foundation/Foundation.h>
 #endif
@@ -84,6 +85,7 @@ extern "C" {
 - (NSString*) stringByUnescapingXML;
 @end
 
+GS_EXPORT_CLASS
 @interface GSXMLDocument : NSObject <NSCopying>
 {
   void	*lib;	// pointer to xmllib pointer of xmlDoc struct
@@ -113,6 +115,7 @@ extern "C" {
 
 
 
+GS_EXPORT_CLASS
 @interface GSXMLNamespace : NSObject <NSCopying>
 {
   void	*lib;          /* pointer to struct xmlNs in the gnome xmllib */
@@ -134,6 +137,7 @@ extern "C" {
 
 /* XML Node */
 
+GS_EXPORT_CLASS
 @interface GSXMLNode : NSObject <NSCopying>
 {
   void  *lib;      /* pointer to struct xmlNode from libxml */
@@ -183,10 +187,12 @@ extern "C" {
 
 @end
 
+GS_EXPORT_CLASS
 @interface GSXMLAttribute : GSXMLNode
 - (NSString*) value;
 @end
 
+GS_EXPORT_CLASS
 @interface GSXMLParser : NSObject
 {
    id			src;		/* source for parsing	*/
@@ -222,6 +228,8 @@ extern "C" {
 	withContentsOfURL: (NSURL*)url;
 - (id) initWithSAXHandler: (GSSAXHandler*)handler
 		 withData: (NSData*)data;
+- (id) initWithSAXHandler: (GSSAXHandler*)handler
+	 withInputStream: (NSInputStream*)stream;
 
 - (BOOL) keepBlanks: (BOOL)yesno;
 - (NSInteger) lineNumber;
@@ -230,16 +238,19 @@ extern "C" {
 - (BOOL) parse: (NSData*)data;
 - (NSString*) publicID;
 - (void) saveMessages: (BOOL)yesno;
+- (BOOL) resolveEntities: (BOOL)yesno;
 - (BOOL) substituteEntities: (BOOL)yesno;
 - (NSString*) systemID;
 
 @end
 
+GS_EXPORT_CLASS
 @interface GSHTMLParser : GSXMLParser
 {
 }
 @end
 
+GS_EXPORT_CLASS
 @interface GSSAXHandler : NSObject
 {
   void		*lib;	// xmlSAXHandlerPtr
@@ -346,9 +357,11 @@ extern "C" {
 
 @end
 
+GS_EXPORT_CLASS
 @interface GSTreeSAXHandler : GSSAXHandler
 @end
 
+GS_EXPORT_CLASS
 @interface GSHTMLSAXHandler : GSSAXHandler
 @end
 
@@ -380,6 +393,7 @@ extern "C" {
  * NSLog (@"Got %@", [result stringValue]);
  *
  */
+GS_EXPORT_CLASS
 @interface GSXPathContext : NSObject
 {
   void		*_lib;		// xmlXPathContext
@@ -401,6 +415,7 @@ extern "C" {
  * the returned type of each GSXPath query to make sure it's what you
  * meant it to be.
  */
+GS_EXPORT_CLASS
 @interface GSXPathObject : NSObject
 {
   void		*_lib;		// xmlXPathObject
@@ -411,6 +426,7 @@ extern "C" {
 /**
  * For XPath queries returning true/false.
  */
+GS_EXPORT_CLASS
 @interface GSXPathBoolean : GSXPathObject
 - (BOOL) booleanValue;
 @end
@@ -418,6 +434,7 @@ extern "C" {
 /**
  * For XPath queries returning a number.
  */
+GS_EXPORT_CLASS
 @interface GSXPathNumber : GSXPathObject
 - (double) doubleValue;
 @end
@@ -425,6 +442,7 @@ extern "C" {
 /**
  * For XPath queries returning a string.
  */
+GS_EXPORT_CLASS
 @interface GSXPathString : GSXPathObject
 - (NSString *) stringValue;
 @end
@@ -432,6 +450,7 @@ extern "C" {
 /**
  * For XPath queries returning a node set.
  */
+GS_EXPORT_CLASS
 @interface GSXPathNodeSet : GSXPathObject
 - (NSUInteger) count;
 - (NSUInteger) length;
@@ -524,13 +543,21 @@ extern "C" {
  * containing the fault details.
  * </p>
  */
+GS_EXPORT_CLASS
 @interface	GSXMLRPC : NSObject <NSURLHandleClient>
 {
 @private
+#if	defined(GNUSTEP)
   NSURLHandle		*handle;
+  NSString		*connectionURL GS_UNUSED_IVAR;
+  NSURLConnection	*connection GS_UNUSED_IVAR;
+  NSMutableData		*response GS_UNUSED_IVAR;
+#else
+  id			handle GS_UNUSED_IVAR;
   NSString		*connectionURL;
   NSURLConnection	*connection;
   NSMutableData		*response;
+#endif
   NSTimer		*timer;
   id			result;
   id			delegate;	// Not retained.
@@ -694,9 +721,10 @@ extern "C" {
 - (void) setCompact: (BOOL)flag;
 
 /**
- * Specify whether to perform debug trace on I/O
+ * Specify whether to perform debug trace on I/O<br />
+ * Return the previous value
  */
-- (void) setDebug: (BOOL)flag;
+- (int) setDebug: (int)flag;
 
 /**
  * Sets the delegate object which will receive callbacks when an XMLRPC
